@@ -234,7 +234,8 @@ class Geocoding(object):
 
 def geotransform2mapinfo(gt, prj):
     # type: (Union[list, tuple, None], Union[str, None]) -> list
-    """Builds an ENVI geo info from given GDAL GeoTransform and Projection (compatible with UTM and LonLat projections).
+    """Build an ENVI geo info from given GDAL GeoTransform and Projection (compatible with UTM and LonLat projections).
+
     :param gt:  GDAL GeoTransform, e.g. (249885.0, 30.0, 0.0, 4578615.0, 0.0, -30.0)
     :param prj: GDAL Projection - WKT Format
     :returns:   ENVI geo info, e.g. [ UTM , 1 , 1 , 256785.0 , 4572015.0 , 30.0 , 30.0 , 43 , North , WGS-84 ]
@@ -278,7 +279,7 @@ def geotransform2mapinfo(gt, prj):
 
 def mapinfo2geotransform(map_info):
     # type: (Union[list, None]) -> tuple
-    """Builds GDAL GeoTransform tuple from an ENVI geo info.
+    """Build GDAL GeoTransform tuple from an ENVI geo info.
 
     :param map_info: ENVI geo info (list), e.g., ['UTM', 1, 1, 192585.0, 5379315.0, 30.0, 30.0, 41, 'North', 'WGS-84']
     :returns:        GDAL GeoTransform, e.g. [249885.0, 30.0, 0.0, 4578615.0, 0.0, -30.0]
@@ -313,7 +314,7 @@ def mapinfo2geotransform(map_info):
 
 
 def get_corner_coordinates(gdal_ds=None, gt=None, cols=None, rows=None):
-    """Returns (ULxy, LLxy, LRxy, URxy) in the same coordinate units like the given geotransform."""
+    """Return (ULxy, LLxy, LRxy, URxy) in the same coordinate units like the given geotransform."""
     assert gdal_ds or (gt and cols and rows), \
         "GEOP.get_corner_coordinates: Missing argument! Please provide either 'gdal_ds' or 'gt', 'cols' AND 'rows'."
 
