@@ -38,7 +38,7 @@ gdal_env.try2set_GDAL_DATA()
 
 def get_proj4info(proj=None):
     # type: (Union[str, int]) -> str
-    """Returns PROJ4 formatted projection info for the given projection.
+    """Return PROJ4 formatted projection info for the given projection.
 
     e.g. '+proj=utm +zone=43 +datum=WGS84 +units=m +no_defs '
 
@@ -49,7 +49,8 @@ def get_proj4info(proj=None):
 
 def proj4_to_dict(proj4):
     # type: (str) -> dict
-    """Converts a PROJ4-like string into a dictionary.
+    """Convert a PROJ4-like string into a dictionary.
+
     :param proj4:   <str> the PROJ4-like string
     """
     return CRS.from_proj4(proj4).to_dict()
@@ -57,7 +58,8 @@ def proj4_to_dict(proj4):
 
 def dict_to_proj4(proj4dict):
     # type: (dict) -> str
-    """Converts a PROJ4-like dictionary into a PROJ4 string.
+    """Convert a PROJ4-like dictionary into a PROJ4 string.
+
     :param proj4dict:   <dict> the PROJ4-like dictionary
     """
     return CRS.from_dict(proj4dict).to_proj4()
@@ -65,7 +67,8 @@ def dict_to_proj4(proj4dict):
 
 def proj4_to_WKT(proj4str):
     # type: (str) -> str
-    """Converts a PROJ4-like string into a WKT string.
+    """Convert a PROJ4-like string into a WKT string.
+
     :param proj4str:   <dict> the PROJ4-like string
     """
     return CRS.from_proj4(proj4str).to_wkt()
@@ -73,7 +76,7 @@ def proj4_to_WKT(proj4str):
 
 def prj_equal(prj1, prj2):
     # type: (Union[None, int, str], Union[None, int, str]) -> bool
-    """Checks if the given two projections are equal.
+    """Check if the given two projections are equal.
 
     :param prj1: projection 1 (WKT or 'epsg:1234' or <EPSG_int>)
     :param prj2: projection 2 (WKT or 'epsg:1234' or <EPSG_int>)
@@ -146,7 +149,8 @@ def EPSG2WKT(EPSG_code):
 
 def WKT2EPSG(wkt):
     # type: (str) -> Union[int, None]
-    """ Transform a WKT string to an EPSG code
+    """Transform a WKT string to an EPSG code.
+
     :param wkt:  WKT definition
     :returns:    EPSG code
     """
@@ -180,7 +184,8 @@ def get_UTMzone(prj):
 
 def get_prjLonLat(fmt='wkt'):
     # type: (str) -> Union[str, dict]
-    """Returns standard geographic projection (EPSG 4326) in the WKT or PROJ4 format.
+    """Return standard geographic projection (EPSG 4326) in the WKT or PROJ4 format.
+
     :param fmt:     <str> target format - 'WKT' or 'PROJ4'
     """
     if not re.search('wkt', fmt, re.I) or re.search('Proj4', fmt, re.I):
